@@ -72,6 +72,7 @@ class Importer(BaseAction):
                 svc.force_machine)
 
             if svc.expose:
+                self.log.info(" Exposing service %r" % svc.name)
                 self.env.expose(svc.name)
 
             if self.options.deploy_delay:
@@ -133,6 +134,8 @@ class Importer(BaseAction):
 
     def run(self):
         self.start_time = time.time()
+        if self.options.bootstrap:
+            self.env.bootstrap()
         self.env.connect()
 
         # Get charms
