@@ -65,6 +65,11 @@ def setup_parser():
         "-b", '--branch-only', action="store_true",
         help='Update vcs branches and exit.',
         dest="branch_only")
+    parser.add_argument(
+        '-B', '--bootstrap',
+        help=('Bootstrap specified environment, blocks until ready'),
+        dest="bootstrap", action="store_true",
+        default=False)
     parser.add_argument(
         '-s', '--deploy-delay', action='store', type=float,
         help=("Time in seconds to sleep between 'deploy' commands, "
