@@ -64,6 +64,16 @@ class BaseEnvironment(object):
                         units.append(uid)
         return units
 
+    def bootstrap(self):
+        self.log.info("bootstraping, this might take a while...")
+        params = self._named_env(["juju", "bootstrap"])
+        self._check_call(
+            params, self.log, "Failed to bootstrap")
+
+        # block until topology is returned
+        self.get_cli_status()
+        self.log.info(" Bootstrap complete")
+
     def deploy(self, name, charm_url,
                repo=None, config=None,
                constraints=None, num_units=1, force_machine=None):
@@ -82,12 +92,17 @@ class BaseEnvironment(object):
                     repo = "."
                 params.extend(["--repository=%s" % repo])
             if force_machine is not None:
-                params.extend(["--to=%d" % force_machine])
+                params.extend(["--to=%s" % force_machine])
 
             params.extend([charm_url, name])
             self._check_call(
                 params, self.log, "Error deploying service %r", name)
 
+    def expose(self, name):
+        params = self._named_env(["juju", "expose", name])
+        self._check_call(
+            params, self.log, "Error exposing service %r", name)
+
     def terminate_machine(self, mid, wait=False):
         """Terminate a machine.
 
@@ -96,7 +111,9 @@ class BaseEnvironment(object):
         delete the machine (ie units have finished executing stop hooks and are
         removed)
         """
-        if int(mid) == 0:
+        if (isinstance(mid, int) and mid == 0) or (
+            mid.isdigit() and int(mid) == 0):
+            # Don't kill state server
             raise RuntimeError("Can't terminate machine 0")
         params = self._named_env(["juju", "terminate-machine"])
         params.append(mid)
