@@ -61,6 +61,9 @@ class GoEnvironment(BaseEnvironment):
                 status["machines"]["0"]["dns-name"])
         return status
 
+    def expose(self, name):
+        return self.client.expose(name)
+
     def reset(self,
               terminate_machines=False,
               terminate_delay=0,
