@@ -58,3 +58,25 @@ class DeploymentTest(Base):
         self.assertEqual(
             [('nginx', 'wordpress'), ('wordpress', 'mysql')],
             list(d.get_relations()))
+
+    def test_multiple_relations_weighted(self):
+        data = {
+            "relations": {
+                "keystone": {
+                    "weight": 100,
+                    "consumes": ["mysql"]
+                },
+                "nova-compute": {
+                    "weight": 50,
+                    "consumes": ["mysql"]
+                },
+                "glance": {
+                    "weight": 70,
+                    "consumes": ["mysql"]
+                },
+            }
+        }
+        d = Deployment("foo", data, include_dirs=())
+        self.assertEqual(
+            [('keystone', 'mysql'), ('glance', 'mysql'),
+             ('nova-compute', 'mysql')], list(d.get_relations()))
