@@ -1,13 +1,19 @@
 from copy import deepcopy
 from contextlib import contextmanager
 
+import errno
 import logging
 from logging.config import dictConfig as logConfig
-import os
 
-from os.path import abspath, isabs
-from os.path import join as path_join
-from os.path import exists as path_exists
+import os
+from os.path import (
+    abspath,
+    expanduser,
+    isabs,
+    isdir,
+    join as path_join,
+    exists as path_exists,
+)
 
 import stat
 import subprocess
@@ -221,3 +227,18 @@ def resolve_include(fname, include_dirs):
             return full_path
 
     return None
+
+
+def mkdir(path):
+    """Create a leaf directory and all intermediate ones.
+
+    Also expand ~ and ~user constructions.
+    If path exists and it's a directory, return without errors.
+    """
+    path = expanduser(path)
+    try:
+        os.makedirs(path)
+    except OSError as err:
+        # Re-raise the error if the target path exists but it is not a dir.
+        if (err.errno != errno.EEXIST) or (not isdir(path)):
+            raise
